//象形柱状图 
function pictorialBar(id, dataName, dataArr) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataArr: dataArr,
            dataName: dataName
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            grid: {
                left: '4%',
                top: '20%',
                bottom: '4%',
                right: '4%',
                containLabel: true
            },
            xAxis: {
                data: dataName,
                axisTick: {
                    show: false
                },
                axisLine: {
                    lineStyle: {
                        color: 'rgba(255, 129, 109,.1)',
                        width: 1 //这里是为了突出显示加上的
                    }
                },
                axisLabel: {
                    textStyle: {
                        color: '#ffffff',
                        fontSize: 12
                    }
                }
            },
            yAxis: [{
                axisTick: {
                    show: false
                },
                axisLine: {
                    show: false
                },
                axisLabel: {
                    show: false
                },
                splitLine: {
                    show: false,
                }
            }],
            series: [{
                type: 'pictorialBar',
                barCategoryGap: '-100%',
                symbol: 'path://M0,10 L10,10 C5.5,10 5.5,5 5,0 C4.5,5 4.5,10 0,10 z',
                label: {
                    show: true,
                    position: 'top',
                    distance: 8, //距离图形元素的距离
                    color: '#fff',
                    fontWeight: 'bolder',
                    fontSize: 15,
                },
                itemStyle: {
                    normal: {
                        color: function(params) {
                            var colorList = [
                                ['rgba(209,158,66,.85)', 'rgba(208,63,60,.95)'],
                                ['rgba(218,180,203,.85)', 'rgba(224,7,160,.95)'],
                                ['rgba(224,186,149,.85)', 'rgba(209,138,60,.95)'],
                                ['rgba(207,223,158,.85)', 'rgba(176,179,76,.95)'],
                                ['rgba(14,209,231,.85)', 'rgba(2,165,244,.95)'],
                                ['rgba(50,185,240,.85)', 'rgba(60,191,221,.95)'],
                                ['rgba(125,201,215,.85)', 'rgba(82,184,186,.95)'],
                            ];
                            var index = params.dataIndex;
                            if (params.dataIndex >= colorList.length) {
                                index = params.dataIndex - colorList.length;
                            }
                            return new echarts.graphic.LinearGradient(0, 0, 0, 1, [
                                { offset: 0, color: colorList[index][0] },
                                { offset: 0.5, color: colorList[index][0] },
                                { offset: 1, color: colorList[index][1] },
                            ]);
                        }
                    }
                },
                data: dataArr
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 柱状图
function barChart(id, dataName, dataArr, colorArr, xName, yName, legendName) {
    // document.getElementById(id).style.display = 'block';
    console.log(id);
    console.log(dataArr);

    var myChart = echarts.init(document.getElementById(id));
    let _arr = [];
    if (dataArr && dataArr.length > 0) {
        _arr = [];
        for (let i = 0; i < dataArr.length; i++) {
            _arr.push({
                name: legendName[i],
                type: 'bar',
                barWidth: 10,
                data: dataArr[i],
                // itemStyle: {
                //     color: new echarts.graphic.LinearGradient(
                //         0, 0, 0, 1, [
                //             { offset: 0, color: colorArr[i][0] },
                //             { offset: 1, color: colorArr[i][1] }
                //         ]
                //     )
                // },
            })
        }
    } else {
        _arr = [];
    }

    function fetchData(cb) {
        cb({
            dataName: dataName,
            colorArr: colorArr,
            dataArr: dataArr,
            yName: yName
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            legend: {},
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            grid: {
                top: '10%',
                left: '4%',
                right: '4%',
                bottom: '6%',
                containLabel: true
            },
            xAxis: [{
                type: 'category',
                name: xName,
                nameLocation: "middle",
                nameGap: 24,
                data: dataName,
            }],
            yAxis: [{
                type: 'value',
                name: yName
            }],
            series: _arr
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 饼图
function pieChart01(id, dataName, colorArr, position, radiusP, centerP, dataArr) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            colorArr: colorArr,
            position: position,
            radiusP: radiusP,
            centerP: centerP,
            dataArr: dataArr
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            tooltip: {
                trigger: 'item',
                formatter: '{b}: {d}%'
            },
            color: data.colorArr,
            series: [{
                type: 'pie',
                radius: data.radiusP,
                center: data.centerP,
                clockwise: false,
                avoidLabelOverlap: false,
                color: [{
                        type: 'linear',
                        x: 1,
                        y: 0,
                        x2: 0,
                        y2: 0,
                        colorStops: [{
                            offset: 0,
                            color: colorArr[0][0] // 0% 处的颜色
                        }, {
                            offset: 1,
                            color: colorArr[0][1] // 100% 处的颜色
                        }]
                    }, {
                        type: 'linear',
                        x: 1,
                        y: 0,
                        x2: 0,
                        y2: 0,
                        colorStops: [{
                            offset: 0,
                            color: colorArr[1][0] // 0% 处的颜色
                        }, {
                            offset: 1,
                            color: colorArr[1][1] // 100% 处的颜色
                        }]
                    },
                    {
                        type: 'linear',
                        x: 1,
                        y: 0,
                        x2: 0,
                        y2: 0,
                        colorStops: [{
                            offset: 0,
                            color: colorArr[2][0] // 0% 处的颜色
                        }, {
                            offset: 1,
                            color: colorArr[2][1] // 100% 处的颜色
                        }]
                    },
                    {
                        type: 'linear',
                        x: 1,
                        y: 0,
                        x2: 0,
                        y2: 0,
                        colorStops: [{
                            offset: 0,
                            color: colorArr[3][0] // 0% 处的颜色
                        }, {
                            offset: 1,
                            color: colorArr[3][1] // 100% 处的颜色
                        }]
                    },
                    {
                        type: 'linear',
                        x: 1,
                        y: 0,
                        x2: 0,
                        y2: 0,
                        colorStops: [{
                            offset: 0,
                            color: colorArr[4][0] // 0% 处的颜色
                        }, {
                            offset: 1,
                            color: colorArr[4][1] // 100% 处的颜色
                        }]
                    },
                    {
                        type: 'linear',
                        x: 1,
                        y: 0,
                        x2: 0,
                        y2: 0,
                        colorStops: [{
                            offset: 0,
                            color: colorArr[5][0] // 0% 处的颜色
                        }, {
                            offset: 1,
                            color: colorArr[5][1] // 100% 处的颜色
                        }]
                    },
                    {
                        type: 'linear',
                        x: 1,
                        y: 0,
                        x2: 0,
                        y2: 0,
                        colorStops: [{
                            offset: 0,
                            color: colorArr[6][0] // 0% 处的颜色
                        }, {
                            offset: 1,
                            color: colorArr[6][1] // 100% 处的颜色
                        }]
                    }, 'transparent'
                ],
                label: {
                    show: true,
                    position: 'outside',
                    formatter: '{b}\n{d}%',
                    // formatter: '{b}<br/>{d}%',
                    color: '#ffffff',
                },
                labelLine: {
                    normal: {
                        length: 5,
                        length2: 10,
                        lineStyle: {
                            width: 1
                        }
                    }
                },
                data: data.dataArr
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 折线图
function lineBarChart(id, dataName, dataArr, colorArr) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            dataArr: dataArr
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    lineStyle: {
                        color: {
                            type: 'linear',
                            x: 0,
                            y: 0,
                            x2: 0,
                            y2: 1,
                            colorStops: [{
                                offset: 0,
                                color: 'rgba(0, 255, 233,0)'
                            }, {
                                offset: 0.5,
                                color: 'rgba(255, 255, 255,1)',
                            }, {
                                offset: 1,
                                color: 'rgba(0, 255, 233,0)'
                            }],
                            global: false
                        }
                    },
                },
            },
            grid: {
                top: '14%',
                left: '4%',
                right: '4%',
                bottom: '0%',
                containLabel: true
            },
            xAxis: [{
                type: 'category',
                axisLine: {
                    show: false
                },
                splitArea: {
                    show: false,
                },
                axisLabel: {
                    show: true,
                    textStyle: {
                        color: '#ffffff',
                    },
                },
                splitLine: {
                    show: false
                },
                axisTick: {
                    show: false,
                },
                boundaryGap: false,
                data: dataName,
            }],
            yAxis: [{
                type: 'value',
                splitLine: {
                    show: true,
                    lineStyle: {
                        color: '#13447c'
                    }
                },
                axisLine: {
                    show: false,
                },
                axisTick: {
                    show: false,
                },
                axisLabel: {
                    show: true,
                    margin: 20,
                    textStyle: {
                        color: '#ffffff',
                    },
                },
            }],
            series: [{
                    name: '',
                    type: 'line',
                    // smooth: true, //是否平滑
                    showAllSymbol: true,
                    // symbol: 'image://.https://zg.sdlibsafe.com/pic/images/guang-circle.png',
                    symbol: 'circle',
                    symbolSize: 8,
                    lineStyle: {
                        normal: {
                            color: "#6c50f3",
                            shadowColor: 'rgba(0, 0, 0, .3)',
                            shadowBlur: 0,
                            shadowOffsetY: 5,
                            shadowOffsetX: 5,
                        },
                    },
                    label: {
                        show: true,
                        position: 'top',
                        textStyle: {
                            color: '#6c50f3',
                        }
                    },
                    itemStyle: {
                        color: "#6c50f3",
                        borderColor: "#fff",
                        borderWidth: 1,
                        shadowColor: 'rgba(0, 0, 0, .3)',
                        shadowBlur: 0,
                        shadowOffsetY: 2,
                        shadowOffsetX: 2,
                    },
                    tooltip: {
                        show: false
                    },
                    areaStyle: {
                        normal: {
                            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
                                    offset: 0,
                                    color: 'rgba(108,80,243,0.3)'
                                },
                                {
                                    offset: 1,
                                    color: 'rgba(108,80,243,0)'
                                }
                            ], false),
                            shadowColor: 'rgba(108,80,243, 0.9)',
                            shadowBlur: 20
                        }
                    },
                    data: dataArr[0]
                },
                {
                    type: 'bar',
                    barWidth: 10,
                    data: dataArr[1],
                    itemStyle: {
                        color: new echarts.graphic.LinearGradient(
                            0, 0, 0, 1, [
                                { offset: 0, color: colorArr[0] },
                                { offset: 1, color: colorArr[1] }
                            ]
                        )
                    },
                }
            ]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 堆叠柱状图
function barChartStack(id, dataName, dataArr, bWidth, xName, yName, colorArr) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            dataArr: dataArr,
            colorArr: colorArr,
            bWidth: bWidth,
            xName: xName,
            yName: yName,
        });
    }
    myChart.showLoading();

    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            color: data.colorArr,
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            legend: {},
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: [{
                type: 'category',
                data: dataName,
            }],
            yAxis: [{
                type: 'value',
                name: yName,
            }],
            series: [{
                    name: '充电',
                    type: 'bar',
                    stack: 'ah',
                    emphasis: {
                        focus: 'series'
                    },
                    barWidth: data.bWidth,
                    data: dataArr[0]
                },
                {
                    name: '放电',
                    type: 'bar',
                    stack: 'ah',
                    emphasis: {
                        focus: 'series'
                    },
                    data: dataArr[1]
                },
                {
                    name: '空闲',
                    type: 'bar',
                    stack: 'ah',
                    emphasis: {
                        focus: 'series'
                    },
                    data: dataArr[2]
                },
                {
                    name: '离线',
                    type: 'bar',
                    stack: 'ah',
                    emphasis: {
                        focus: 'series'
                    },
                    data: dataArr[3]
                },
            ]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 柱状图
function barChart01(id, dataName, dataArr, bWidth, yName, colorArr) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            dataArr: dataArr,
            colorArr: colorArr,
            bWidth: bWidth,
            yName: yName,
        });
    }
    myChart.showLoading();

    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            color: data.colorArr,
            tooltip: {
                trigger: 'axis',
                axisPointer: {
                    type: 'shadow'
                }
            },
            grid: {
                top: '20%',
                left: '4%',
                right: '4%',
                bottom: '4%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: dataName
            },
            yAxis: {
                type: 'value',
                name: yName,
            },
            series: [{
                data: dataArr,
                type: 'bar',
                barWidth: data.bWidth,
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 饼状图
function pieChart(id, dataName, colorArr, nameS, radiusP, centerP, dataArr) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            colorArr: colorArr,
            nameS: nameS,
            radiusP: radiusP,
            centerP: centerP,
            dataArr: dataArr
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            tooltip: {
                trigger: 'item',
                // formatter: "{a} <br/>{b}: {c} ({d}%)"
                formatter: "{b}:<br/>{c} ({d}%)"
            },
            legend: {
                type: 'scroll',
                orient: 'vertical',
                x: 'right',
                data: data.dataName
            },
            color: data.colorArr,
            series: [{
                name: data.nameS,
                type: 'pie',
                radius: data.radiusP,
                center: data.centerP,
                avoidLabelOverlap: false,
                label: {
                    normal: {
                        show: false,
                        position: 'center'
                    },
                    emphasis: {
                        show: true,
                        textStyle: {
                            fontSize: '14',
                            fontWeight: 'bold'
                        }
                    }
                },
                labelLine: {
                    normal: {
                        show: false
                    }
                },
                data: data.dataArr
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 单折线图
function lineChart01(id, dataName, colorArr, legendName, dataArr) {
    var myChart = echarts.init(document.getElementById(id));
    let _arr = [];
    for (let i = 0; i < dataArr.length; i++) {
        _arr.push({
            type: 'line',
            name: legendName[i],
            areaStyle: {},
            data: dataArr[i]
        })
    }

    function fetchData(cb) {
        cb({
            dataName: dataName,
            colorArr: colorArr,
            legendName: legendName,
            dataArr: dataArr
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            tooltip: {
                trigger: 'axis',
            },
            legend: {
                data: legendName
            },
            grid: {
                left: '3%',
                right: '4%',
                bottom: '3%',
                containLabel: true
            },
            xAxis: [{
                type: 'category',
                boundaryGap: false,
                data: dataName
            }],
            yAxis: [{
                type: 'value'
            }],
            color: data.colorArr,
            series: _arr
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 单折线图
function lineChart02(id, dataName, colorArr, legendName, dataArr) {
    console.log(dataArr);
    var myChart = echarts.init(document.getElementById(id));
    let _arr = [];
    for (let i = 0; i < dataArr.length; i++) {
        _arr.push({
            type: 'line',
            name: legendName[i],
            smooth: true,
            data: dataArr[i],
        });
    }

    function fetchData(cb) {
        cb({
            dataName: dataName,
            legendName: legendName,
            colorArr: colorArr,
            dataArr: dataArr
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            color: data.colorArr,
            legend: {
                data: legendName
            },
            tooltip: {
                trigger: 'axis',
                formatter: function(value) {
                    let _data = value[0].data;
                    return _data.value[0] + '<br>' + _data.value[1];
                },
                axisPointer: {
                    animation: false
                }
            },
            grid: {
                top: '8%',
                left: '3%',
                right: '4%',
                bottom: '18%',
                containLabel: true
            },
            xAxis: {
                type: 'time',
                splitLine: {
                    show: true
                }
            },
            yAxis: {
                type: 'value',
                boundaryGap: [0, '100%'],
                splitLine: {
                    show: true
                }
            },
            dataZoom: [{
                    type: 'inside',
                    start: 0,
                    end: 100
                },
                {
                    start: 0,
                    end: 100
                }
            ],
            series: _arr
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 单折线图
function lineChart03(id, dataName, colorArr, legendName, dataArr, title, yName) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            legendName: legendName,
            colorArr: colorArr,
            dataArr: dataArr
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            color: data.colorArr,
            title: {
                text: title,
                // left: 'center'
            },
            tooltip: {
                trigger: 'axis'
            },
            grid: {
                top: '20%',
                left: '3%',
                right: '4%',
                bottom: '4%',
                containLabel: true
            },
            // legend: {},
            toolbox: {
                show: true,
                feature: {
                    dataZoom: {
                        yAxisIndex: 'none'
                    },
                    dataView: { readOnly: false },
                    magicType: { type: ['line', 'bar'] },
                    restore: {},
                    saveAsImage: {}
                }
            },
            xAxis: {
                type: 'category',
                boundaryGap: false,
                data: dataName
            },
            yAxis: {
                type: 'value',
                name: yName
                    // axisLabel: {
                    //     formatter: '{value}'
                    // }
            },
            series: [{
                name: 'Highest',
                type: 'line',
                data: dataArr,
                markPoint: {
                    data: [
                        { type: 'max', name: 'Max' },
                        { type: 'min', name: 'Min' }
                    ]
                },
                markLine: {
                    data: [{ type: 'average', name: 'Avg' }]
                }
            }, ]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 散点图
function scatterChart(id, dataArr, xName, yName, zName, arrRange, cutNum) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataArr: dataArr,
            xName: xName,
            yName: yName,
            zName: zName,
            arrRange: arrRange,
            cutNum: cutNum
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            grid: {
                top: '10%',
                left: '1%',
                right: '4%',
                bottom: '8%',
                containLabel: true
            },
            tooltip: {
                trigger: 'item',
                formatter: function(param) {
                    let val = param.value;
                    return data.zName + ': ' + (val[2]) + "%";
                }
            },
            // 区域缩放控制
            toolbox: {
                feature: {
                    dataZoom: {
                        // yAxisIndex: 'none'
                    },
                    restore: {},
                    // saveAsImage: {}
                }
            },
            xAxis: [{
                type: 'value',
                name: data.xName,
                nameLocation: "middle",
                nameGap: 35,
                min: arrRange[0],
                max: arrRange[1],
                splitNumber: cutNum,
                axisTick: { length: 10 },
                gridIndex: 0,
                splitLine: {
                    show: true
                }
            }],
            yAxis: [{
                type: 'value',
                name: data.yName,
                min: arrRange[0],
                max: arrRange[1],
                splitNumber: cutNum,
                axisTick: { length: 10 },
                splitLine: {
                    show: true
                },
            }],
            visualMap: [{
                type: 'piecewise',
                min: 0,
                max: 100,
                range: [0, 99],
                pieces: [
                    { min: 11, max: 100, color: '#002329' },
                    { min: 8, max: 11, color: '#00474f' },
                    { min: 5, max: 8, color: '#006d75' },
                    { min: 2, max: 5, color: '#08979c' },
                    { min: 0, max: 2, color: '#13c2c2' }
                ],
                text: ['High', 'Low'],
                selectedMode: 'multiple',
                align: 'auto', // 自动决定。'left' 图形在左文字在右。'right' 图形在右文字在左。
                textGap: 20, //两端文字主体之间的距离
                itemGap: 10, //每两个图元之间的间隔距离，单位为px。
                itemSymbol: 'circle', //图形的形状 'rect', 'roundRect', 'triangle', 'diamond', 'pin', 'arrow'
                show: true, //是否显示组件
                left: "right",
                top: '22%',
                hoverLink: true,
            }],
            series: [{
                type: 'scatter',
                // name: ['开始SOC', '结束SOC', 'numn'],
                name: [data.zName],
                itemStyle: {
                    normal: {
                        opacity: 1
                    }
                },
                symbol: 'rect', //散点图展示样式
                symbolSize: [50, 10], //散点尺寸大小
                // symbolSize: function(val) {
                //     let size_val = val[2];
                //     if (size_val > 30 && size_val <= 100) {
                //         return 50;
                //     } else if (size_val > 20 && size_val <= 30) {
                //         return 45;
                //     } else if (size_val > 10 && size_val <= 20) {
                //         return 40;
                //     } else if (size_val > 5 && size_val <= 10) {
                //         return 30;
                //     } else if (size_val > 0 && size_val <= 5) {
                //         return 20;
                //     } else {
                //         return 0;
                //     }
                // },
                data: data.dataArr,
                animation: false //解决echart转图片时,图片为空的问题
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}