let colorArrData = ['#f00', '#009587', '#f90', '#0072bd', '#b200bd', '#16bd00', '#93bd00'];
// 折线图01 -异步加载
function lineChart(id, dataName, dataArr, xName, yName, r, color) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            dataArr: dataArr,
            xName: xName,
            yName: yName,
            r: r,
            color: color
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            color: color,
            tooltip: {
                trigger: 'axis'
            },
            grid: {
                left: '1.5%',
                right: '2.8%',
                bottom: '10%',
                top: '10%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: data.dataName,
                name: data.xName,
                nameLocation: "middle",
                nameGap: 35,
                nameTextStyle: {
                    color: '#000000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    textStyle: {
                        color: '#000000',
                    },
                    rotate: data.r
                },
            },
            yAxis: {
                type: 'value',
                name: data.yName,
                nameGap: 5,
                nameTextStyle: {
                    color: '#000000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    color: '#000000',
                    formatter: function(value) {
                        // return toThousands(parseInt(value));
                        return value;
                    }
                },
            },
            series: [{
                data: data.dataArr,
                type: 'line',
                // smooth: true,
                animation: false //解决echart转图片时,图片为空的问题
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}

// 柱状图
function barChart(id, dataName, colorArr, nameS, dataArr, bWidth, r, xName, yName, markLine, range, warnData) {
    var myChart = echarts.init(document.getElementById(id));
    let _markLine = markLine.sort(function(a, b) { return a - b });
    let _min = null,
        _max = null;
    if (range && range.length > 0) {
        _min = range[0];
        _max = range[1];
    } else {
        _min = null;
        _max = null;
    }
    // 突出报警编号
    if (warnData && warnData.length > 0) {
        for (let i = 0; i < warnData.length; i++) {
            dataArr.splice(warnData[i], 1, {
                value: dataArr[warnData[i]],
                itemStyle: { color: '#a90000' }
            });
        }
    }

    function fetchData(cb) {
        cb({
            dataName: dataName,
            colorArr: colorArr,
            nameS: nameS,
            dataArr: dataArr,
            bWidth: bWidth,
            r: r,
            xName: xName,
            yName: yName,
            markLine: markLine
        });
    }
    myChart.showLoading();
    // 警戒线
    var _html = [],
        color = ["#ffec3d", "#fa8c16", "#cf1322"]; //黄   橙  红
    if (markLine && markLine.length > 0) {
        _html = [];
        for (let i = 0; i < markLine.length; i++) {
            _html.push({
                name: '警戒线', //name
                yAxis: (markLine[i]).toString(), //值
                lineStyle: { //警戒线的样式  ，虚实  颜色
                    // color: "rgba(255,0,0,.5)"
                    color: color[i],
                    width: 2
                }
            });
        }
    } else {
        _html = [];
    }
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            color: data.colorArr,
            tooltip: {
                trigger: 'axis',
                axisPointer: { // 坐标轴指示器，坐标轴触发有效
                    type: 'shadow' // 默认为直线，可选为：'line' | 'shadow'
                },
                // formatter: function(param) {
                //     if (flag == '%') {
                //         return `${param[0].axisValue}: ${param[0].value}%`;
                //     }
                //     return `${param[0].axisValue}: ${param[0].value}`
                // }
            },
            legend: {
                orient: 'vertical',
                x: 'right',
            },
            grid: {
                left: '1.5%',
                right: '6.8%',
                bottom: '8%',
                top: '8%',
                containLabel: true
            },
            xAxis: [{
                type: 'category',
                data: data.dataName,
                name: data.xName, //坐标轴名称
                nameLocation: "middle", //坐标轴名称显示位置。可选：'start','middle','end'
                nameGap: 27, //坐标轴名称与轴线之间的距离
                axisTick: {
                    alignWithLabel: true
                },
                nameTextStyle: {
                    color: '#000000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    textStyle: {
                        color: '#000000',
                    },
                    rotate: data.r
                },
            }],
            yAxis: [{
                type: 'value',
                name: data.yName,
                nameGap: 8,
                nameRotate: 0,
                nameTextStyle: {
                    color: '#000000'
                },
                min: function(value) {
                    if (_min) {
                        return _min;
                    } else {
                        return value.min;
                    }
                },
                max: function(value) {
                    if (_markLine && _markLine.length > 0) {
                        let len = _markLine.length;
                        if (value.max < _markLine[len - 1]) {
                            return _markLine[len - 1];
                        }
                    }
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    color: '#000000',
                    formatter: function(value) {
                        return value;
                        // return toThousands(parseInt(value));
                    }
                },
            }],
            series: [{
                name: data.nameS,
                type: 'bar',
                barWidth: data.bWidth,
                data: dataArr,
                // 警戒线
                markLine: {
                    symbol: "none", //去掉警戒线最后面的箭头
                    slient: false, //鼠标悬停事件true没有，false有
                    data: _html, //警戒线取值
                },
                itemStyle: {
                    color: new echarts.graphic.LinearGradient(
                        0, 0, 0, 1, [
                            { offset: 0, color: colorArr[0] },
                            { offset: 1, color: colorArr[1] }
                        ]
                    )
                },
                animation: false //解决echart转图片时,图片为空的问题
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 多条折线图 -异步加载
function lineCharts(id, dataName, dataArr, xName, yName, r, warnData) {

    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            dataArr: dataArr,
            xName: xName,
            yName: yName,
            r: r,
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        var _html01 = [];
        for (let i = 0; i < dataArr.length; i++) {
            _html01.push({
                data: dataArr[i],
                type: 'line',
                symbol: 'triangle', //设置拐点处的图标
                smooth: true, //设置折线是否为平滑
                tooltip: {
                    formatter: function(value) {
                        let _text = `<div class="tooltipText">
                                        <p class="tooltipTextLeft">${'时间: '+value.data.value[0] }</p>
                                        <p class="tooltipTextLeft">${'编号: ' + value.data.num}</p>
                                        <p class="tooltipTextLeft">${'值: '+value.data.value[1]}</p>
                                    </div>`;
                        return _text;
                    },
                },
                animation: false //解决echart转图片时,图片为空的问题
            });
        }
        if (warnData && warnData.length > 0) {
            for (let i = 0; i < warnData.length; i++) {
                // 删除报警线
                _html01.splice(warnData[i], 1);
                // 最后添加报警线
                _html01.push({
                    data: dataArr[warnData[i]],
                    type: 'line',
                    lineStyle: {
                        color: colorArrData[i],
                        width: 4
                    },
                    symbol: 'circle', //设置拐点处的图标
                    symbolSize: 8,
                    itemStyle: {
                        color: colorArrData[i],
                    },
                    smooth: true, //设置折线是否为平滑
                    tooltip: {
                        formatter: function(value) {
                            // console.log('-------------value---------------');
                            // console.log(value);
                            let _text = `<div class="tooltipText">
                                            <p class="tooltipTextLeft">${'时间: '+value.data.value[0] }</p>
                                            <p class="tooltipTextLeft">${'编号: ' + value.data.num}</p>
                                            <p class="tooltipTextLeft">${'值: '+value.data.value[1]}</p>
                                        </div>`;
                            return _text;
                        },
                    },
                    animation: false //解决echart转图片时,图片为空的问题
                });
            }
        }
        option = {
            color: ['#a8a8a8'],
            tooltip: {
                trigger: 'item',
            },
            grid: {
                left: '0.5%',
                right: '2.8%',
                bottom: '8%',
                top: '10%',
                containLabel: true
            },
            xAxis: {
                type: 'time',
                // boundaryGap: true, //坐标是否从0开始
                data: data.dataName,
                name: data.xName,
                nameLocation: "middle",
                nameGap: 35,
                splitNumber: 20,
                nameTextStyle: {
                    color: '#000000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    textStyle: {
                        color: '#000000',
                    },
                    formatter: function(value) {
                        const date = new Date(value)
                        const texts = [date.getFullYear(), (date.getMonth() + 1), date.getDate()];
                        return texts.join('-');
                    },
                    rotate: data.r
                },
            },
            yAxis: {
                type: 'value',
                name: data.yName,
                nameGap: 5,
                nameRotate: 0,
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                nameTextStyle: {
                    lineHeight: 21, //行高
                    color: '#000000'
                },
                // 刻度标签
                axisLabel: {
                    color: '#000000',
                    // formatter: function(value) {
                    //     // return toThousands(parseInt(value));
                    //     return value;
                    // }
                },
            },
            series: _html01,
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 折线图-中
function lineChartM(id, dataName, dataArr, xName, yName, r, color, markLine) {

    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            dataArr: dataArr,
            xName: xName,
            yName: yName,
            r: r,
            color: color,
            markLine: markLine
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        var _html = [],
            _obj01 = {};
        if (markLine && markLine.length > 0) {
            _html = [];
            for (let i = 0; i < markLine.length; i++) {
                _obj01 = {};
                if (markLine[i] || markLine[i] == 0) {
                    _obj01 = {
                        name: '警戒线', //name
                        yAxis: (markLine[i]).toString(), //值
                        lineStyle: { //警戒线的样式  ，虚实  颜色
                            // color: "rgba(255,0,0,.5)"
                            color: "#cf1322",
                            width: 2
                        },
                    };
                }
                _html.push(_obj01);
            }
        } else {
            _html = [];
        }
        console.log(_html);
        option = {
            color: color,
            tooltip: {
                trigger: 'axis'
            },
            grid: {
                left: '2%',
                right: '8.8%',
                bottom: '10%',
                top: '10%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: data.dataName,
                name: data.xName,
                nameLocation: "middle",
                nameGap: 35,
                nameTextStyle: {
                    color: '#000000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    textStyle: {
                        color: '#000000',
                    },
                    rotate: data.r
                },
            },
            yAxis: {
                type: 'value',
                name: data.yName,
                nameGap: 15,
                max: function(value) {
                    if (markLine[0] && value.max < markLine[0]) {
                        return markLine[0];
                    } else {
                        return value.max
                    }
                },
                min: function(value) {
                    if (markLine[1] && value.min > markLine[1]) {
                        return markLine[1];
                    } else {
                        return value.min
                    }
                },
                nameTextStyle: {
                    color: '#000000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    color: '#000000',
                    formatter: function(value) {
                        return value;
                    }
                },
            },
            series: [{
                data: dataArr,
                type: 'line',
                smooth: true,
                symbol: 'triangle', //设置拐点处的图标
                // 警戒线
                markLine: {
                    symbol: "none", //去掉警戒线最后面的箭头
                    slient: false, //鼠标悬停事件true没有，false有
                    data: _html, //警戒线取值
                },
                animation: false //解决echart转图片时,图片为空的问题
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}

function lineChartM01(id, dataName, dataArr, xName, yName, r, color, markLine) {

    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            dataArr: dataArr,
            xName: xName,
            yName: yName,
            r: r,
            color: color,
            markLine: markLine
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        var _html = [],
            _obj01 = {};
        if (markLine && markLine.length > 0) {
            _html = [];
            for (let i = 0; i < markLine.length; i++) {
                _obj01 = {};
                if (markLine[i] || markLine[i] == 0) {
                    _obj01 = {
                        name: '警戒线', //name
                        yAxis: (markLine[i]).toString(), //值
                        lineStyle: { //警戒线的样式  ，虚实  颜色
                            // color: "rgba(255,0,0,.5)"
                            color: "#cf1322",
                            width: 2
                        },
                    };
                }
                _html.push(_obj01);
            }
        } else {
            _html = [];
        }
        option = {
            color: color,
            tooltip: {
                trigger: 'axis'
            },
            grid: {
                left: '2%',
                right: '8.8%',
                bottom: '10%',
                top: '10%',
                containLabel: true
            },
            xAxis: {
                type: 'category',
                data: data.dataName,
                name: data.xName,
                nameLocation: "middle",
                nameGap: 35,
                nameTextStyle: {
                    color: '#000000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    textStyle: {
                        color: '#000000',
                    },
                    rotate: data.r
                },
            },
            yAxis: {
                type: 'value',
                name: data.yName,
                nameGap: 15,
                max: function(value) {
                    if (markLine[0] && value.max < markLine[0]) {
                        return markLine[0];
                    } else {
                        return value.max
                    }
                },
                // min: function(value) {
                //     if (markLine[1] && value.min > markLine[1]) {
                //         return markLine[1];
                //     } else {
                //         return value.min
                //     }
                // },
                nameTextStyle: {
                    color: '#000000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    color: '#000000',
                    formatter: function(value) {
                        // return toThousands(parseInt(value));
                        return value;
                    }
                },
            },
            series: [{
                data: dataArr,
                type: 'line',
                smooth: true,
                symbol: 'triangle', //设置拐点处的图标
                // 警戒线
                markLine: {
                    symbol: "none", //去掉警戒线最后面的箭头
                    slient: false, //鼠标悬停事件true没有，false有
                    data: _html, //警戒线取值
                },
                animation: false //解决echart转图片时,图片为空的问题
            }]
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 多线图-中
function lineChartsM(id, dataName, dataArr, xName, yName, r, makeLine) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataName: dataName,
            dataArr: dataArr,
            xName: xName,
            yName: yName,
            r: r,
            makeLine: makeLine
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        var _html01 = [];
        for (let i = 0; i < dataArr.length; i++) {
            _html01.push({
                data: dataArr[i],
                type: 'line',
                symbol: 'triangle', //设置拐点处的图标
                smooth: true, //设置折线是否为平滑
                // series.tooltip 仅在 tooltip.trigger 为 'item' 时有效。
                tooltip: {
                    formatter: function(value) {
                        let _text = `<div class="tooltipText">
                                        <p class="tooltipTextLeft">${'时间: '+value.data.value[0] }</p>
                                        <p class="tooltipTextLeft">${'编号: ' + value.data.num}</p>
                                        <p class="tooltipTextLeft">${'值: '+value.data.value[1]}</p>
                                    </div>`;
                        return _text;
                    },
                },
                animation: false //解决echart转图片时,图片为空的问题
            });
        }
        if (makeLine && makeLine.length > 0) {
            console.log('makeLine存在');
            for (let i = 0; i < makeLine.length; i++) {
                // 删除报警线
                _html01.splice(makeLine[i], 1);
                // 最后添加报警线
                _html01.push({
                    data: dataArr[makeLine[i]],
                    type: 'line',
                    symbol: 'circle', //设置拐点处的图标
                    smooth: true, //设置折线是否为平滑
                    symbolSize: 8,
                    itemStyle: {
                        color: colorArrData[i],
                    },
                    // 特殊线加粗红色提示
                    lineStyle: {
                        color: colorArrData[i],
                        width: 4
                    },
                    // series.tooltip 仅在 tooltip.trigger 为 'item' 时有效。
                    tooltip: {
                        formatter: function(value) {
                            let _text = `<div class="tooltipText">
                                            <p class="tooltipTextLeft">${'时间: '+value.data.value[0] }</p>
                                            <p class="tooltipTextLeft">${'编号: ' + value.data.num}</p>
                                            <p class="tooltipTextLeft">${'值: '+value.data.value[1]}</p>
                                        </div>`;
                            return _text;
                        },
                    },
                    animation: false //解决echart转图片时,图片为空的问题
                });
            }
        }
        option = {
            color: ['#a8a8a8'],
            tooltip: {
                trigger: 'item', //坐标轴触发，可设为 item 数据项图形触发
            },
            grid: {
                left: '0.5%',
                right: '2.8%',
                bottom: '10%',
                top: '10%',
                containLabel: true
            },
            xAxis: {
                type: 'time',
                // boundaryGap: true, //坐标是否从0开始
                data: data.dataName,
                name: data.xName,
                nameLocation: "middle",
                nameGap: 35,
                splitNumber: 20,
                nameTextStyle: {
                    color: '#000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    textStyle: {
                        color: '#000'
                    },
                    formatter: function(value) {
                        const date = new Date(value)
                        const texts = [date.getFullYear(), (date.getMonth() + 1), date.getDate()];
                        return texts.join('-');
                    },
                    rotate: data.r
                },
            },
            yAxis: {
                type: 'value',
                name: data.yName,
                nameGap: 5,
                nameRotate: 0,
                nameTextStyle: {
                    lineHeight: 21, //行高
                    color: '#000'
                },
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                // 刻度标签
                axisLabel: {
                    color: '#000'
                    // formatter: function(value) {
                    //     return value;
                    // }
                },
            },
            series: _html01,
        };
        myChart.setOption(option);
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 散点图
function scatterChart(id, dataArr, xName, yName, color) {
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataArr: dataArr,
            xName: xName,
            yName: yName,
            color: color
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            tooltip: {
                trigger: 'item',
                formatter: function(param) {
                    return param.data[0] + ': ' + param.data[1];
                }
            },
            grid: {
                left: '2%',
                right: '3%',
                bottom: '6%',
                top: '10%',
                containLabel: true
            },
            xAxis: {
                name: xName,
                nameLocation: "middle",
                nameGap: 24,
                nameTextStyle: {
                    color: '#000000'
                },
                scale: true, //是否是脱离 0 值比例。设置成 true 后坐标刻度不会强制包含零刻度。在双数值轴的散点图中比较有用。
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    textStyle: {
                        color: '#000000',
                    },
                    rotate: data.r
                },
            },
            yAxis: {
                name: yName,
                nameGap: 40,
                nameLocation: 'middle',
                nameRotate: 90,
                nameTextStyle: {
                    color: '#000000'
                },
                scale: true, //是否是脱离 0 值比例。设置成 true 后坐标刻度不会强制包含零刻度。在双数值轴的散点图中比较有用。
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisLabel: {
                    color: '#000000',
                    formatter: function(value) {
                        return value;
                    }
                },
                splitLine: {
                    show: false,
                }
            },
            series: [{
                type: 'scatter',
                symbol: 'circle',
                symbolSize: 8,
                data: dataArr,
                itemStyle: {
                    opacity: 1,
                    color: color,
                    // borderWidth: 1,
                },
                animation: false //解决echart转图片时,图片为空的问题               
            }]
        };
        myChart.setOption(option);
        if (id == 'chartDC01') {
            console.log('chart -----  DC01');
            let picInfo = myChart.getDataURL();
            if (picInfo) {
                $('#imgDC01').html(`<img src='${picInfo}'>`);
            } else {
                $('#imgDC01').html(`<span>暂无数据</span>`);
            }
        }
        if (id == 'chartDC02') {
            console.log('chart -----  DC02');
            let picInfo = myChart.getDataURL();
            if (picInfo) {
                $('#imgDC02').html(`<img src='${picInfo}'>`);
            } else {
                $('#imgDC02').html(`<span>暂无数据</span>`);
            }
        }
        if (id == 'chartDC03') {
            console.log('chart -----  DC03');
            let picInfo = myChart.getDataURL();
            if (picInfo) {
                $('#imgDC03').html(`<img src='${picInfo}'>`);
            } else {
                $('#imgDC03').html(`<span>暂无数据</span>`);
            }
        }
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}
// 散点图
function scatterChart01(id, dataArr, xName, yName, color, length, rotate) {
    console.log(length);
    console.log(dataArr);
    var myChart = echarts.init(document.getElementById(id));

    function fetchData(cb) {
        cb({
            dataArr: dataArr,
            xName: xName,
            yName: yName,
            color: color
        });
    }
    myChart.showLoading();
    fetchData(function(data) {
        myChart.hideLoading();
        option = {
            tooltip: {
                trigger: 'item',
                formatter: function(param) {
                    return param.data[0] + ': ' + param.data[1];
                }
            },
            grid: {
                left: '2%',
                right: '3%',
                bottom: '6%',
                top: '10%',
                containLabel: true
            },
            xAxis: {
                name: xName,
                nameLocation: "middle",
                nameGap: 24,
                nameTextStyle: {
                    color: '#000000'
                },
                // scale: true, //是否是脱离 0 值比例。设置成 true 后坐标刻度不会强制包含零刻度。在双数值轴的散点图中比较有用。
                splitNumber: length,
                max: length,
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: false,
                    alignWithLabel: false
                },
                splitLine: {
                    show: false
                },
                axisLabel: {
                    textStyle: {
                        color: '#000000',
                    },
                    rotate: rotate
                },
            },
            yAxis: {
                name: yName,
                nameGap: 40,
                nameLocation: 'middle',
                nameRotate: 90,
                nameTextStyle: {
                    color: '#000000'
                },
                scale: true, //是否是脱离 0 值比例。设置成 true 后坐标刻度不会强制包含零刻度。在双数值轴的散点图中比较有用。
                axisLine: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisTick: {
                    show: true,
                    lineStyle: {
                        color: '#42a4ff',
                    }
                },
                axisLabel: {
                    color: '#000000',
                    formatter: function(value) {
                        return value;
                    }
                },
                splitLine: {
                    show: false,
                }
            },
            series: [{
                type: 'scatter',
                symbol: 'circle',
                symbolSize: 8,
                data: dataArr,
                itemStyle: {
                    opacity: 1,
                    color: color,
                    // borderWidth: 1,
                },
                animation: false //解决echart转图片时,图片为空的问题               
            }]
        };
        myChart.setOption(option);
        if (id == 'last_bat_vol') {
            console.log('last_bat_vol -----  DC01');
            let picInfo = myChart.getDataURL();
            if (picInfo) {
                $('#last_bat_vol_img').html(`<img src='${picInfo}'>`);
            } else {
                $('#last_bat_vol_img').html(`<span>暂无数据</span>`);
            }
        }
    });
    // 图表自适应
    window.addEventListener('resize', () => {
        myChart.resize();
    });
}